@@ -1,12 +1,15 @@
+import importlib.util
+import sys
 import typing as t
 from tempfile import NamedTemporaryFile
+from textwrap import dedent
 
 import pytest
 from docutils.nodes import document
 from docutils.writers import Writer
 from sphinx.application import Sphinx
 from sphinx.io import read_doc
-from sphinx.testing.fixtures import make_app, test_params
+from sphinx.testing.fixtures import make_app, test_params  # noqa
 from sphinx.testing.path import path as STP
 from sphinx.util import rst
 from sphinx.util.docutils import sphinx_domains
@@ -49,3 +52,21 @@ def render() -> t.Callable[[Sphinx, document], str]:
         return writer.output
 
     return _render
+
+
+@pytest.fixture
+def make_module():
+    added_modules = []
+
+    def make_module(name, code):
+        assert name not in sys.modules
+        spec = importlib.util.spec_from_loader(name, loader=None)
+        mod = sys.modules[name] = importlib.util.module_from_spec(spec)
+        exec(dedent(code), mod.__dict__)
+        added_modules.append(name)
+        return mod
+
+    yield make_module
+
+    for name in added_modules:
+        del sys.modules[name]
